@@ -77,7 +77,7 @@ class BccClient(bce_base_client.BceBaseClient):
               memory_capacity_in_gb=int,
               image_id=(bytes, str))  # ***Unicode***
     def create_instance(self, cpu_count, memory_capacity_in_gb, image_id, instance_type=None,
-                        billing=None, create_cds_list=None, root_disk_size_in_gb = 0, root_disk_storage_type = None,
+                        billing=None, create_cds_list=None, root_disk_size_in_gb=0, root_disk_storage_type=None,
                         network_capacity_in_mbps=0, purchase_count=1, cardCount=1, name=None,
                         admin_pass=None, zone_name=None, subnet_id=None, security_group_id=None,
                         gpuCard=None, fpgaCard=None,
@@ -431,7 +431,7 @@ class BccClient(bce_base_client.BceBaseClient):
         return self._send_request(http_methods.PUT, path, params=params, config=config)
 
     @required(instance_id=(bytes, str))  # ***Unicode***
-    def stop_instance(self, instance_id, force_stop=False, config=None):
+    def stop_instance(self, instance_id, force_stop=False, stopWithNoCharge=False, config=None):
         """
         Stopping the instance owned by the user.
         You can stop the instance only when the instance is Running,
@@ -455,7 +455,8 @@ class BccClient(bce_base_client.BceBaseClient):
         instance_id = compat.convert_to_bytes(instance_id)
         path = b'/instance/%s' % instance_id
         body = {
-            'forceStop': force_stop
+            'forceStop': force_stop,
+            'stopWithNoCharge': stopWithNoCharge
         }
         params = {
             'stop': None
@@ -791,6 +792,12 @@ class BccClient(bce_base_client.BceBaseClient):
     @required(instance_id=(bytes, str),
               tags=list)
     def bind_instance_to_tags(self, instance_id, tags, config=None):
+        """
+        :param instance_id:
+        :param tags:
+        :param config:
+        :return:
+        """
         instance_id = compat.convert_to_bytes(instance_id)
         path = b'/instance/%s/tag' % instance_id
         tag_list = [tag.__dict__ for tag in tags]
@@ -806,6 +813,12 @@ class BccClient(bce_base_client.BceBaseClient):
     @required(instance_id=(bytes, str),
               tags=list)
     def unbind_instance_from_tags(self, instance_id, tags, config=None):
+        """
+        :param instance_id:
+        :param tags:
+        :param config:
+        :return:
+        """
         instance_id = compat.convert_to_bytes(instance_id)
         path = b'/instance/%s/tag' % instance_id
         tag_list = [tag.__dict__ for tag in tags]
@@ -1337,6 +1350,12 @@ class BccClient(bce_base_client.BceBaseClient):
                                 volume_id,
                                 cdsName,
                                 config=None):
+        """
+        :param volume_id:
+        :param cdsName:
+        :param config:
+        :return:
+        """
         volume_id = compat.convert_to_bytes(volume_id)
         path = b'/volume/%s' % volume_id
 
@@ -1354,6 +1373,12 @@ class BccClient(bce_base_client.BceBaseClient):
                                 volume_id,
                                 billing=None,
                                 config=None):
+        """
+        :param volume_id:
+        :param billing:
+        :param config:
+        :return:
+        """
         volume_id = compat.convert_to_bytes(volume_id)
         path = b'/volume/%s' % volume_id
 
@@ -1564,6 +1589,13 @@ class BccClient(bce_base_client.BceBaseClient):
                           name,
                           destRegions,
                           config=None):
+        """
+        :param image_id:
+        :param name:
+        :param destRegions:
+        :param config:
+        :return:
+        """
         image_id = compat.convert_to_bytes(image_id)
         path = b'/image/%s' % image_id
 
@@ -1581,6 +1613,11 @@ class BccClient(bce_base_client.BceBaseClient):
     def cancle_remote_copy_image(self,
                                  image_id,
                                  config=None):
+        """
+        :param image_id:
+        :param config:
+        :return:
+        """
         image_id = compat.convert_to_bytes(image_id)
         path = b'/image/%s' % image_id
 
@@ -1595,6 +1632,13 @@ class BccClient(bce_base_client.BceBaseClient):
                     account=None,
                     account_id=None,
                     config=None):
+        """
+        :param image_id:
+        :param account:
+        :param account_id:
+        :param config:
+        :return:
+        """
         image_id = compat.convert_to_bytes(image_id)
         path = b'/image/%s' % image_id
 
@@ -1616,6 +1660,13 @@ class BccClient(bce_base_client.BceBaseClient):
                     account=None,
                     account_id=None,
                     config=None):
+        """
+        :param image_id:
+        :param account:
+        :param account_id:
+        :param config:
+        :return:
+        """
         image_id = compat.convert_to_bytes(image_id)
         path = b'/image/%s' % image_id
 
@@ -1635,6 +1686,11 @@ class BccClient(bce_base_client.BceBaseClient):
     def list_shared_user(self,
                          image_id,
                          config=None):
+        """
+        :param image_id:
+        :param config:
+        :return:
+        """
         image_id = compat.convert_to_bytes(image_id)
         path = b'/image/%s/sharedUsers' % image_id
         return self._send_request(http_methods.GET, path, config=config)
@@ -1643,6 +1699,11 @@ class BccClient(bce_base_client.BceBaseClient):
     def list_os(self,
                 instance_ids=None,
                 config=None):
+        """
+        :param instance_ids:
+        :param config:
+        :return:
+        """
         path = b'/image/os'
         instance_id_list = instance_ids
         body = {
@@ -1883,9 +1944,7 @@ class BccClient(bce_base_client.BceBaseClient):
         :rtype baidubce.bce_response.BceResponse
         """
         path = b'/securityGroup'
-        params = None
-        if instance_id is not None or marker is not None or max_keys is not None:
-            params = {}
+        params = {}
         if instance_id is not None:
             params['instanceId'] = instance_id
         if vpc_id is not None:
@@ -2018,7 +2077,15 @@ class BccClient(bce_base_client.BceBaseClient):
                    retention_days=None,
                    client_token=None,
                    config=None):
-
+        """
+        :param asp_name:
+        :param time_points:
+        :param repeat_week_days:
+        :param retention_days:
+        :param client_token:
+        :param config:
+        :return:
+        """
         path = b'/asp'
         params = None
         if client_token is None:
@@ -2044,7 +2111,12 @@ class BccClient(bce_base_client.BceBaseClient):
                    asp_id=None,
                    volume_ids=None,
                    config=None):
-
+        """
+        :param asp_id:
+        :param volume_ids:
+        :param config:
+        :return:
+        """
         asp_id = compat.convert_to_bytes(asp_id)
         path = b'/asp/%s' % asp_id
 
@@ -2063,7 +2135,12 @@ class BccClient(bce_base_client.BceBaseClient):
                    asp_id=None,
                    volume_ids=None,
                    config=None):
-
+        """
+        :param asp_id:
+        :param volume_ids:
+        :param config:
+        :return:
+        """
         asp_id = compat.convert_to_bytes(asp_id)
         path = b'/asp/%s' % asp_id
 
@@ -2080,12 +2157,24 @@ class BccClient(bce_base_client.BceBaseClient):
     def delete_asp(self,
                    asp_id=None,
                    config=None):
-
+        """
+        :param asp_id:
+        :param config:
+        :return:
+        """
         asp_id = compat.convert_to_bytes(asp_id)
         path = b'/asp/%s' % asp_id
         return self._send_request(http_methods.DELETE, path, config=config)
 
     def list_asps(self, marker=None, max_keys=None, asp_name=None, volume_name=None, config=None):
+        """
+        :param marker:
+        :param max_keys:
+        :param asp_name:
+        :param volume_name:
+        :param config:
+        :return:
+        """
         path = b'/asp'
         params = None
         if marker is not None or max_keys is not None or asp_name is not None or volume_name is not None:
@@ -2102,6 +2191,11 @@ class BccClient(bce_base_client.BceBaseClient):
 
     @required(asp_id=(bytes, str))
     def get_asp(self, asp_id=None, config=None):
+        """
+        :param asp_id:
+        :param config:
+        :return:
+        """
         asp_id = compat.convert_to_bytes(asp_id)
         path = b'/asp/%s' % asp_id
         return self._send_request(http_methods.GET, path, config=config)
@@ -2116,6 +2210,12 @@ class BccClient(bce_base_client.BceBaseClient):
                        keypair_name=None,
                        keypair_desc=None,
                        config=None):
+        """
+        :param keypair_name:
+        :param keypair_desc:
+        :param config:
+        :return:
+        """
         path = b'/keypair'
         body = {
             'name': keypair_name,
@@ -2134,6 +2234,13 @@ class BccClient(bce_base_client.BceBaseClient):
                        keypair_desc=None,
                        public_key=None,
                        config=None):
+        """
+        :param keypair_name:
+        :param keypair_desc:
+        :param public_key:
+        :param config:
+        :return:
+        """
         path = b'/keypair'
         body = {
             'name': keypair_name,
@@ -2149,6 +2256,12 @@ class BccClient(bce_base_client.BceBaseClient):
                                   params=params, config=config)
 
     def list_keypairs(self, marker=None, max_keys=None, config=None):
+        """
+        :param marker:
+        :param max_keys:
+        :param config:
+        :return:
+        """
         path = b'/keypair'
         params = None
         if marker is not None or max_keys is not None:
@@ -2161,6 +2274,11 @@ class BccClient(bce_base_client.BceBaseClient):
 
     @required(keypair_id=(bytes, str))
     def get_keypair(self, keypair_id=None, config=None):
+        """
+        :param keypair_id:
+        :param config:
+        :return:
+        """
         keypair_id = compat.convert_to_bytes(keypair_id)
         path = b'/keypair/%s' % keypair_id
         return self._send_request(http_methods.GET, path, config=config)
@@ -2171,6 +2289,12 @@ class BccClient(bce_base_client.BceBaseClient):
                        keypair_id=None,
                        instance_ids=None,
                        config=None):
+        """
+        :param keypair_id:
+        :param instance_ids:
+        :param config:
+        :return:
+        """
 
         keypair_id = compat.convert_to_bytes(keypair_id)
         path = b'/keypair/%s' % keypair_id
@@ -2189,6 +2313,12 @@ class BccClient(bce_base_client.BceBaseClient):
                        keypair_id=None,
                        instance_ids=None,
                        config=None):
+        """
+        :param keypair_id:
+        :param instance_ids:
+        :param config:
+        :return:
+        """
 
         keypair_id = compat.convert_to_bytes(keypair_id)
         path = b'/keypair/%s' % keypair_id
@@ -2205,6 +2335,11 @@ class BccClient(bce_base_client.BceBaseClient):
     def delete_keypair(self,
                        keypair_id=None,
                        config=None):
+        """
+        :param keypair_id:
+        :param config:
+        :return:
+        """
 
         keypair_id = compat.convert_to_bytes(keypair_id)
         path = b'/keypair/%s' % keypair_id
@@ -2217,6 +2352,12 @@ class BccClient(bce_base_client.BceBaseClient):
                        keypair_id=None,
                        keypair_name=None,
                        config=None):
+        """
+        :param keypair_id:
+        :param keypair_name:
+        :param config:
+        :return:
+        """
 
         keypair_id = compat.convert_to_bytes(keypair_id)
         path = b'/keypair/%s' % keypair_id
@@ -2236,6 +2377,12 @@ class BccClient(bce_base_client.BceBaseClient):
                             keypair_id=None,
                             keypair_desc=None,
                             config=None):
+        """
+        :param keypair_id:
+        :param keypair_desc:
+        :param config:
+        :return:
+        """
 
         keypair_id = compat.convert_to_bytes(keypair_id)
         path = b'/keypair/%s' % keypair_id
