@@ -184,13 +184,14 @@ class BosClient(BceBaseClient):
                            config=config)
 
     @required(bucket_name=(bytes, str))
-    def set_bucket_storage_class(self, bucket_name, storage_class=None, config=None):
+    def set_bucket_storage_class(self, bucket_name, storage_class, config=None):
         """
 
         :param bucket_name:
         :param config:
         :return:
         """
+        storage_class = compat.convert_to_string(storage_class)
         return self._send_request(http_methods.PUT,
                            bucket_name,
                            body=json.dumps({'storageClass': storage_class},
@@ -782,7 +783,7 @@ class BosClient(BceBaseClient):
         headers_list = http_response.getheaders()
         if compat.PY3:
             temp_heads = []
-            for k,v in headers_list:
+            for k, v in headers_list:
                 k = k.lower()
                 temp_heads.append((k, v))
             headers_list = temp_heads
