@@ -195,8 +195,6 @@ class MediaClient(BceBaseClient):
             body_content['description'] = ""
         if pipeline_config is not None:
             body_content['config'] = pipeline_config
-        else:
-            body_content['config'] = {'capacity': 20}
         if pipeline_name == '':
             raise BceClientError('pipeline_name can\'t be empty string')
         if source_bucket == '':
@@ -268,12 +266,37 @@ class MediaClient(BceBaseClient):
             video=None,
             encryption=None,
             watermark_id=None,
+            extra_config=None,
+            trans_config=None,
             config=None):
         """
         Create a preset
 
+        :param preset_name: the preset name
+        :type preset_name: string
+        :param container: container of video or audio
+        :type container: string
+        :param transmux: enable transmux
+        :type transmux: boolean
+        :param description: the description of this preset
+        :type description: string
+        :param clip: None
+        :type clip: JSON
+        :param audio: None
+        :type audio: JSON
+        :param video: None
+        :type video: JSON
+        :param encryption: None
+        :type encryption: JSON
+        :param watermark_id: None
+        :type watermark_id: string
+        :param extra_config: None
+        :type extra_config: JSON
+        :param trans_config: None
+        :type trans_config: JSON
         :param config: None
         :type config: BceClientConfiguration
+
         :returns:
         :rtype: baidubce.bce_response.BceResponse
         """
@@ -301,6 +324,10 @@ class MediaClient(BceBaseClient):
             body_content['encryption'] = encryption
         if watermark_id is not None:
             body_content['watermarkId'] = watermark_id
+        if extra_config is not None:
+            body_content['extraCfg'] = extra_config
+        if trans_config is not None:
+            body_content['transCfg'] = trans_config
         return self._send_request(
             http_methods.POST,
             '/preset',
